pub fn noop_halt() -> HaltCallbackExpand description
Returns a HaltCallback that performs no action.
Useful for tests and for writers operating under simulation where halt is observed via the test harness rather than the kernel.
pub fn noop_halt() -> HaltCallbackReturns a HaltCallback that performs no action.
Useful for tests and for writers operating under simulation where halt is observed via the test harness rather than the kernel.